@@ -1,4 +1,4 @@
-# $OpenXM: OpenXM/src/R/r-packages/hgm/R/hgm.cwishart.R,v 1.10 2016/03/01 07:29:18 takayama Exp $
+# $OpenXM: OpenXM/src/R/r-packages/hgm/R/hgm.cwishart.R,v 1.11 2017/03/22 00:42:57 takayama Exp $
 "hgm.tk.pwishart" <-
 function(m=3,n=5,beta=c(1,2,3),q0=0.2,approxdeg=-1,h=0.01,dp=-1,q=10,
          mode=c(1,1,0),method="a-rk4",err=c(-1.0,-1.0),
@@ -13,7 +13,7 @@ function(m=3,n=5,beta=c(1,2,3),q0=0.2,approxdeg=-1,h=0.01,dp=-1,q=10,
   if (!is.loaded("hgm")) library.dynam("hgm",package="hgm",lib.loc=NULL);
 
   .C("Rmh_set_strategy",as.integer(nstrategy),as.double(err),retv=double(1),
-     package="hgm")$retv ;
+     PACKAGE="hgm")$retv ;
 
   if (m<1) m=1;
   rank <- 2^m;
